/*+++*
 *  title:	DefaultsHandler.h
 *  abstract:	Interface of DefaultsHandler class for preferences modules.
 *  author:	Tom Hageman <tom@basil.icce.rug.nl>
 *  created:	March 1999
 *  modified:	(see RCS Log at end)
 *  copyright:
 *
 *		Copyright (C) 1999  Tom R. Hageman.
 *
 *	This is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this software; see the file COPYING.  If not, write to
 *	the Free Software Foundation, 59 Temple Place - Suite 330,
 *	Boston, MA 02111-1307, USA.
 *
 *  description:
 *
 *      This module defines the following classes:
 *      - DefaultsHandler
 *---*/

#ifdef RCS_DefaultsHandler_ID
static const char * const RCS_h_id = ((void)&RCS_h_id,
	"@(#)DefaultsHandler.h,v 1.2 1999/04/08 18:54:00 tom Exp");
#endif

#import <objc/Object.h>
#import <objc/hashtable.h>


@interface DefaultsHandler : Object
{
    id delegate;
    NXAtom nextstepDefaultName;
    NXAtom openstepDefaultName;
}

- delegate;
- (void)setDelegate:aDelegate;

- (NXAtom)nextstepDefaultName;
- (void)setNextstepDefaultName:(const char *)aName;

- (NXAtom)openstepDefaultName;
- (void)setOpenstepDefaultName:(const char *)aName;

- (NXAtom)nextstepGlobalOwner;
- (NXAtom)openstepGlobalOwner;
    // constants.

- (BOOL)setOwner:(const char *)anOwner
    value:(const char *)aValue
    nextstep:(BOOL)nextstep
    openstep:(BOOL)openstep;
    /* set a user default value for owner `anOwner' for NEXTSTEP and/or
       OPENSTEP (with the implicit defaultName keys.)
       Removes the user default if aValue = NULL. */

- (int)scanPreferences:(void *)context;
    /* scan through a list of all user defaults, XXX */

@end // DefaultsHandler


@interface Object (DefaultsHandlerDelegate)
- (BOOL)defaultsHandler:sender
    foundOwner:(NXAtom)anOwner
    nextstepValue:(const char *)nextstepValue
    openstepValue:(const char *)openstepValue
    context:(void *)context;
    /* -scanPreferences callback.  nextstepValue and/or openstepValue
       will be NULL if the owner is not found, and an empty string if the
       owner is found (even when it had no value for the default) */
@end
