#! /bin/sh
#+++
#  title:	setpref.sh
#  abstract:	set user default for NEXTSTEP and/or OPENSTEP.
#  author:	Tom Hageman <tom@basil.icce.rug.nl>
#  created:	November 1997
#  modified:	March 1999
#  copyleft:
#
#	Copyright (C) 1997,1999 Tom R. Hageman, but otherwise perfect freeware.
#
#  description:
#	Usage: setpref [-r] [domain | -g] [-N <NEXTSTEP-key>] [-O <OPENSTEP-key>] value.
#
#	Set (or remove if `-r' is given) user default value in given domain
#	for NEXTSTEP-key and OPENSTEP-key, if present.
#
#	As a special case, NEXTSTEP `GLOBAL' and `System' domains are
#	mapped to OPENSTEP `NSGlobalDomain'.
#
#	NB. should be invoked by `zsh' if available since it is 8-bit clean
#	(`sh' isn't.)  Also system() invokes `sh', so that isn't good enough.
#	This should be safe since DefaultsHandler now only calls this if it
#	tries to set an OPENSTEP value.
#---

PATH=/usr/ucb:/bin:/usr/bin; export PATH

err=/dev/null
#err=/dev/console
#err=/dev/tty

Usage() {
   echo "Usage: `basename $0` [-r] [domain | -g] [-N NEXTSTEP-key] [-O OPENSTEP-key] value" >&2
   exit 2
}

#echo "DEBUG [$0 $@]" >&2
#set -x

case "$1" in
-r) action=dremove; shift ;;
*)  action=dwrite ;;
esac

domain="$1"

case "$2" in
-N) nskey="$3" ;;
-O) oskey="$3" ;;
*)  Usage
esac

case $# in
3|4)
    value="$4" ;;
5|6)
    case "$4" in
    -N) nskey="$5" ;;
    -O) oskey="$5" ;;
    *)  Usage
    esac
    value="$6" ;;  
*)
    Usage
esac

case "$nskey" in
"") ;;
*)
    $action "$domain" "$nskey" "$value" ;;
esac 2>$err

case "$oskey" in
"") ;;
*)
    case "$domain" in
    -g | GLOBAL | System)  domain=NSGlobalDomain
    esac
    case $action in
    dwrite)  defaults write "$domain" "$oskey" "\"$value\"" ;;
    dremove) defaults delete "$domain" "$oskey" ;;
    esac
esac 2>$err
